@@ -12,6 +12,7 @@
 #include <gtk/gtksignal.h>
 #include <gtk/gtkmarshal.h>
 #include <gtk/gtkplug.h>
+#include <gtk/gtkbox.h>
 #include <bonobo/bonobo-main.h>
 #include <bonobo/bonobo-control.h>
 #include <bonobo/bonobo-control-frame.h>
@@ -37,6 +38,7 @@ POA_Bonobo_ControlFrame__vepv bonobo_control_frame_vepv;
 
 struct _BonoboControlFramePrivate {
 	Bonobo_Control	  control;
+	GtkWidget        *container;
 	GtkWidget	 *socket;
 	BonoboUIHandler   *uih;
 	BonoboPropertyBag *propbag;
@@ -197,6 +199,20 @@ bonobo_control_frame_construct (BonoboControlFrame *control_frame,
 	control_frame->priv->socket = gtk_socket_new ();
 	gtk_widget_show (control_frame->priv->socket);
 
+	/*
+	 * Finally, create a box to hold the socket; this no-window
+	 * container is needed solely for the sake of bypassing
+	 * plug/socket in the local case.
+	 */
+	control_frame->priv->container = gtk_hbox_new (1, 0);
+	gtk_container_set_border_width (GTK_CONTAINER (control_frame->priv->container), 0);
+	gtk_box_pack_end (GTK_BOX (control_frame->priv->container),
+			  control_frame->priv->socket,
+			  TRUE, TRUE, 0);
+	gtk_widget_ref (control_frame->priv->container);
+	gtk_object_sink (GTK_OBJECT(control_frame->priv->container));
+	gtk_widget_show (control_frame->priv->container);
+
 	/*
 	 * When the socket is realized, we pass its Window ID to our
 	 * Control.
@@ -246,6 +262,8 @@ bonobo_control_frame_destroy (GtkObject *object)
 		CORBA_exception_free (&ev);
 	}
 	
+	gtk_widget_unref (control_frame->priv->container);
+
 	g_free (control_frame->priv);
 	
 	GTK_OBJECT_CLASS (bonobo_control_frame_parent_class)->destroy (object);
@@ -525,7 +543,7 @@ bonobo_control_frame_get_widget (BonoboControlFrame *control_frame)
 	g_return_val_if_fail (control_frame != NULL, NULL);
 	g_return_val_if_fail (BONOBO_IS_CONTROL_FRAME (control_frame), NULL);
 
-	return control_frame->priv->socket;
+	return control_frame->priv->container;
 }
 
 /**
