@@ -18,6 +18,7 @@
 #include <gdk/gdkprivate.h>
 
 enum {
+	SET_FRAME,
 	ACTIVATE,
 	UNDO_LAST_OPERATION,
 	LAST_SIGNAL
@@ -35,6 +36,7 @@ struct _BonoboControlPrivate {
 	GtkWidget          *plug;
 
 	int                 plug_destroy_id;
+	gboolean            is_local;
 
 	GtkWidget          *widget;
 
@@ -127,8 +129,8 @@ bonobo_control_plug_destroy_cb (GtkWidget *plug, GdkEventAny *event, gpointer cl
 
 static void
 impl_Bonobo_Control_activate (PortableServer_Servant servant,
-			     CORBA_boolean activated,
-			     CORBA_Environment *ev)
+			      CORBA_boolean activated,
+			      CORBA_Environment *ev)
 {
 	BonoboControl *control = BONOBO_CONTROL (bonobo_object_from_servant (servant));
 
@@ -138,7 +140,7 @@ impl_Bonobo_Control_activate (PortableServer_Servant servant,
 
 static void
 impl_Bonobo_Control_reactivate_and_undo (PortableServer_Servant servant,
-					CORBA_Environment *ev)
+					 CORBA_Environment *ev)
 {
 	BonoboControl *control = BONOBO_CONTROL (bonobo_object_from_servant (servant));
 
@@ -148,54 +150,89 @@ impl_Bonobo_Control_reactivate_and_undo (PortableServer_Servant servant,
 	
 static void
 impl_Bonobo_Control_set_frame (PortableServer_Servant servant,
-			      Bonobo_ControlFrame frame,
-			      CORBA_Environment *ev)
+			       Bonobo_ControlFrame frame,
+			       CORBA_Environment *ev)
 {
 	BonoboControl *control = BONOBO_CONTROL (bonobo_object_from_servant (servant));
 
 	bonobo_control_set_control_frame (control, frame);
 }
 
+
+
+static GtkWidget *
+bonobo_gtk_widget_from_x11_id (guint32 xid)
+{
+	GdkWindow *window;
+	gpointer data;
+
+	window = gdk_window_lookup (xid);
+	
+	if (! window) {
+		return NULL;
+	}
+
+	gdk_window_get_user_data(window, &data);
+
+	if (!data || !GTK_IS_WIDGET (data)) {
+		return NULL;
+	} else {
+		return GTK_WIDGET (data);
+	}
+}
+
 static void
 impl_Bonobo_Control_set_window (PortableServer_Servant servant,
-			       Bonobo_Control_windowid id,
-			       CORBA_Environment *ev)
+				Bonobo_Control_windowid id,
+				CORBA_Environment *ev)
 {
 	guint32 x11_id;
+	GtkWidget *local_socket;
 	BonoboControl *control = BONOBO_CONTROL (bonobo_object_from_servant (servant));
 
 	x11_id = window_id_demangle (id);
 
-	control->priv->plug = gtk_plug_new (x11_id);
-	control->priv->plug_destroy_id = gtk_signal_connect (
-		GTK_OBJECT (control->priv->plug), "destroy_event",
-		GTK_SIGNAL_FUNC (bonobo_control_plug_destroy_cb), control);
+	local_socket = bonobo_gtk_widget_from_x11_id(x11_id);
 
+	if (local_socket) {
+		GtkWidget *socket_parent;
+		control->priv->is_local = TRUE;
+		socket_parent = local_socket->parent;
+		gtk_widget_hide(local_socket);
 
-	gtk_container_add (GTK_CONTAINER (control->priv->plug), control->priv->widget);
-
-	gtk_widget_show_all (control->priv->plug);
+		gtk_box_pack_end (GTK_BOX (socket_parent),
+				  control->priv->widget,
+				  TRUE, TRUE, 0);
+	} else {
+		control->priv->plug = gtk_plug_new (x11_id);
+		control->priv->plug_destroy_id = gtk_signal_connect (
+		        GTK_OBJECT (control->priv->plug), "destroy_event",
+		        GTK_SIGNAL_FUNC (bonobo_control_plug_destroy_cb), control);
+		gtk_container_add (GTK_CONTAINER (control->priv->plug), control->priv->widget);
+		gtk_widget_show_all (control->priv->plug);
+	}
 }
 
 static void
 impl_Bonobo_Control_size_allocate (PortableServer_Servant servant,
-				  const CORBA_short width,
-				  const CORBA_short height,
-				  CORBA_Environment *ev)
+				   const CORBA_short width,
+				   const CORBA_short height,
+				   CORBA_Environment *ev)
 {
 	/*
 	 * Nothing.
 	 *
 	 * In the Gnome implementation of Bonobo, all size negotiation
-	 * is handled by GtkPlug/GtkSocket for us.
+	 * is handled by GtkPlug/GtkSocket for us, or GtkFrame in the
+	 * local case.
 	 */
 }
 
 static void
 impl_Bonobo_Control_size_request (PortableServer_Servant servant,
-				 CORBA_short *desired_width,
-				 CORBA_short *desired_height,
-				 CORBA_Environment *ev)
+				  CORBA_short *desired_width,
+				  CORBA_short *desired_height,
+				  CORBA_Environment *ev)
 {
 	/*
 	 * Nothing.
@@ -204,7 +241,7 @@ impl_Bonobo_Control_size_request (PortableServer_Servant servant,
 
 static Bonobo_PropertyBag
 impl_Bonobo_Control_get_property_bag (PortableServer_Servant servant,
-				     CORBA_Environment *ev)
+				      CORBA_Environment *ev)
 {
 	BonoboControl *control = BONOBO_CONTROL (bonobo_object_from_servant (servant));
 	Bonobo_PropertyBag corba_propbag;
@@ -252,7 +289,9 @@ bonobo_control_corba_object_create (BonoboObject *object)
 }
 
 BonoboControl *
-bonobo_control_construct (BonoboControl *control, Bonobo_Control corba_control, GtkWidget *widget)
+bonobo_control_construct (BonoboControl  *control,
+			  Bonobo_Control  corba_control,
+			  GtkWidget      *widget)
 {
 	g_return_val_if_fail (control != NULL, NULL);
 	g_return_val_if_fail (BONOBO_IS_CONTROL (control), NULL);
@@ -327,11 +366,14 @@ bonobo_control_destroy (GtkObject *object)
 	/*
 	 * If the plug still exists, destroy it.  The plug might not
 	 * exist in the case where the container application died,
-	 * taking the plug out with it.  In that case,
-	 * plug_destroy_cb() would have been invoked, and it would
-	 * have triggered the destruction of the Control.  Which is why
-	 * we're here now.
+	 * taking the plug out with it, or the optimized local case
+	 * where the plug/socket mechanism was bypassed.  In the
+	 * formaer case, plug_destroy_cb() would have been invoked,
+	 * and it would have triggered the destruction of the Control,
+	 * which is why we're here now. In the latter case, it's not
+	 * needed because there is no plug.  
 	 */
+
 	if (control->priv->plug) {
 		gtk_signal_disconnect (GTK_OBJECT (control->priv->plug), control->priv->plug_destroy_id);
 		gtk_object_destroy (GTK_OBJECT (control->priv->plug));
@@ -396,6 +438,8 @@ bonobo_control_set_control_frame (BonoboControl *control, Bonobo_ControlFrame co
 	control->priv->control_frame = CORBA_Object_duplicate (control_frame, &ev);
 	
 	CORBA_exception_free (&ev);
+
+	gtk_signal_emit (GTK_OBJECT (control), control_signals [SET_FRAME]);
 }
 
 /**
@@ -547,6 +591,9 @@ bonobo_control_get_remote_ui_handler (BonoboControl *control)
 	g_return_val_if_fail (control != NULL, CORBA_OBJECT_NIL);
 	g_return_val_if_fail (BONOBO_IS_CONTROL (control), CORBA_OBJECT_NIL);
 
+	g_return_val_if_fail (control->priv->control_frame != CORBA_OBJECT_NIL,
+			      CORBA_OBJECT_NIL);
+
 	CORBA_exception_init (&ev);
 
 	uih = Bonobo_ControlFrame_get_ui_handler (control->priv->control_frame, &ev);
@@ -593,6 +640,14 @@ bonobo_control_class_init (BonoboControlClass *klass)
 
 	bonobo_control_parent_class = gtk_type_class (bonobo_object_get_type ());
 
+	control_signals [SET_FRAME] =
+                gtk_signal_new ("set_frame",
+                                GTK_RUN_LAST,
+                                object_class->type,
+                                GTK_SIGNAL_OFFSET (BonoboControlClass, set_frame),
+                                gtk_marshal_NONE__NONE,
+                                GTK_TYPE_NONE, 0);
+
 	control_signals [ACTIVATE] =
                 gtk_signal_new ("activate",
                                 GTK_RUN_LAST,
