@@ -787,7 +787,7 @@ view_factory (BonoboEmbeddable *bonobo_object,
 	gtk_signal_connect (GTK_OBJECT (view), "system_exception",
 			    GTK_SIGNAL_FUNC (view_system_exception_cb), view_data);
 
-	gtk_signal_connect (GTK_OBJECT (view), "view_activate",
+	gtk_signal_connect (GTK_OBJECT (view), "activate",
 			    GTK_SIGNAL_FUNC (view_activate_cb), view_data);
 
 	bonobo_object_data->views = g_list_prepend (bonobo_object_data->views,
