@@ -42,7 +42,7 @@ static EFSDir *
 fsys_open (EFS *efs, const char *path, gint flags, gint mode)
 {
 	FSYSDir *dir;
-	struct flock fl = {F_WRLCK, SEEK_SET, 0, 0};
+//	struct flock fl = {F_WRLCK, SEEK_SET, 0, 0};
 	DIR *d;
 	gchar *p;
 	gint pflags;
